/**********************************************************************************
 * The Configurator allows to easily edit the TS2PerlMod config.
 * Copyright (C) 2006  Felix Siefert
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 **********************************************************************************/

#include <QVBoxLayout>
#include <QHBoxLayout>
#include <QLabel>
#include <QFile>
#include <QFileInfo>
#include <QTextStream>

#include "advertmsg.h"
#include "settings.h"
#include "features.h"
#include "editor.h"

Advertmsg::Advertmsg(QWidget *parent) : QWidget(parent)
{
    m_description = new QLabel(tr("Sends an advert message to all users on the server "
                                  "every certain time interval."));
    m_description->setWordWrap(true);
    m_interval    = new TimeInput(tr("Interval:"), 60);
    m_interval->setTimeMin(60);
    m_editor      = new Editor(false);
    m_editor->setFile("advert.txt");
    
    QVBoxLayout *mainLayout = new QVBoxLayout;
    mainLayout->addWidget(m_description);
    mainLayout->addWidget(m_interval);
    mainLayout->addWidget(m_editor);
    setLayout(mainLayout);
}

void Advertmsg::load(QSettings &settings)
{
    m_interval->setTimeMin(settings.value("ADVERT-MESSAGE/Interval").toInt());
    
    QString path = settings.value("ADVERT-MESSAGE/File").toString();
    if(path.isEmpty())
    {
        return;
    }
    path = QString("text/") + path;
    
    QFile file(path);
    file.open(QIODevice::ReadOnly);
    QTextStream stream(&file);
    
    m_editor->setText(stream.readAll());
    
    QFileInfo info(path);
    m_editor->setFile(info.fileName());
}

void Advertmsg::save(QSettings &settings)
{
    settings.setValue("ADVERT-MESSAGE/Interval", m_interval->getTimeMin());
    
    QString filename = m_editor->getFile();
    settings.setValue("ADVERT-MESSAGE/File", filename);
    QString path = QString("text/") + filename;
    
    QFile file(path);
    file.open(QIODevice::WriteOnly);
    QTextStream stream(&file);
    
    stream << m_editor->getText();
}
