/**********************************************************************************
 * The Configurator allows to easily edit the TS2PerlMod config.
 * Copyright (C) 2006  Felix Siefert
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 **********************************************************************************/

#include <QVBoxLayout>
#include <QHBoxLayout>
#include <QLabel>
#include <QFile>
#include <QFileInfo>
#include <QTextStream>

#include "badnickname.h"
#include "settings.h"
#include "editor.h"
#include "features.h"

Badnickname::Badnickname(QWidget *parent) : QWidget(parent)
{
    m_description = new QLabel(tr("Scans nicknames for bad words. If any of the bad words are included" 
                                  "within the users nickname, the user will be punished. For example, "
                                  "if you make the word <b>butt</b> illegal, the nickname <b>Butthead</b> will also be disallowed."));
    m_description->setWordWrap(true);
    m_editor      = new Editor(false);
    m_editor->setFile("badnicks.txt");
    m_punish      = new Punishment;
    
    QVBoxLayout *mainLayout = new QVBoxLayout;
    mainLayout->addWidget(m_description);
    mainLayout->addWidget(m_punish);
    mainLayout->addWidget(m_editor);
    setLayout(mainLayout);
}

void Badnickname::load(QSettings &settings)
{
    Settings::Pain badnickPain = stringToPain(settings.value("BAD-NICKNAME/Punishment").toString());
    m_punish->setPunish(badnickPain);
    m_punish->setChannel(settings.value("BAD-NICKNAME/Channel").toString());
    if(badnickPain == Settings::MOVE || badnickPain == Settings::REMOVE)
    {
        m_punish->setLabel(settings.value("BAD-NICKNAME/Message").toString());
    }
    else
    {
        m_punish->setLabel(settings.value("BAD-NICKNAME/Reason").toString());
    }
    
    
    QString path = settings.value("BAD-NICKNAME/File").toString();
    if(path.isEmpty())
    {
        return;
    }
    path = QString("text/") + path;
    
    QFile file(path);
    file.open(QIODevice::ReadOnly);
    QTextStream stream(&file);
    
    m_editor->setText(stream.readAll());
    
    QFileInfo info(path);
    m_editor->setFile(info.fileName());
}

void Badnickname::save(QSettings &settings)
{
    settings.setValue("BAD-NICKNAME/Punishment", m_punish->getPunishStr());
    settings.setValue("BAD-NICKNAME/Channel", m_punish->getChannel());
    if(m_punish->getPunish() == Settings::MOVE || m_punish->getPunish() == Settings::REMOVE)
    {
        settings.setValue("BAD-NICKNAME/Message", m_punish->getLabel());
    }
    else
    {
        settings.setValue("BAD-NICKNAME/Reason", m_punish->getLabel());
    }
    
    
    QString filename = m_editor->getFile();
    settings.setValue("BAD-NICKNAME/File", filename);
    QString path = QString("text/") + filename;
    
    QFile file(path);
    file.open(QIODevice::WriteOnly);
    QTextStream stream(&file);
    
    stream << m_editor->getText();
}
