/**********************************************************************************
 * The Configurator allows to easily edit the TS2PerlMod config.
 * Copyright (C) 2006  Felix Siefert
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 **********************************************************************************/

#include <QVBoxLayout>
#include <QHBoxLayout>
#include <QMessageBox>
#include <QTabWidget>
#include <QLabel>
#include <QPushButton>
#include <QCheckBox>
#include <QFileDialog>
#include <QDebug>
#include <QSettings>
#include <QFile>
#include <QFileInfo>
#include <QDir>
#include <QInputDialog>
#include <QTextStream>
#include <QRegExp>

#include "configurator.h"
#include "settings.h"
#include "common.h"
#include "features.h"
#include "extendedmsg.h"
#include "badnickname.h"
#include "badchannel.h"
#include "advertmsg.h"
#include "statsmsg.h"
#include "protuser.h"

Configurator::Configurator(QWidget *parent) : QMainWindow(parent)
{ 
    setWindowTitle("Configurator 0.6 RC3");
    
    QWidget *centralWidget = new QWidget;
    setCentralWidget(centralWidget);
    
    m_tabWidget = new QTabWidget;
    m_copyright = new QLabel(QChar(169) +  QString(" Felix Siefert"));
    m_copyright->setToolTip(tr("Configurator version 0.6 RC3, Copyright (C) 2006-2007 Felix Siefert\n\n"
                               "This program comes with ABSOLUTELY NO WARRANTY;\n"
                               "This is free software, and you are welcome to redistribute "
                               "it under certain conditions;"));
    m_currentFile = new QLabel;
    m_loadBtn   = new QPushButton(tr("Load"));
    m_saveasBtn = new QPushButton(tr("Save As..."));
    m_saveBtn   = new QPushButton(tr("Save"));
    
    connect(m_loadBtn, SIGNAL(clicked()), this, SLOT(showLoadDialog()));
    connect(m_saveasBtn, SIGNAL(clicked()), this, SLOT(showSaveAsDialog()));
    connect(m_saveBtn, SIGNAL(clicked()), this, SLOT(showSaveDialog()));
    
    /* commonTab */
    m_commonTab = new Common;
    m_tabWidget->addTab(m_commonTab, tr("Basics"));
    
    /* featuresTab */
    m_featuresTab = new Features;
    m_tabWidget->addTab(m_featuresTab, tr("Features"));
    
    /* extendedmsgTab */
    m_extendedmsgTab = new Extendedmsg;
    connect(m_featuresTab->m_extendedmsg, SIGNAL(toggled(bool)),
            this, SLOT(toggleExtendedmsgTab(bool)));
    
    /* badnicknameTab */
    m_badnicknameTab = new Badnickname;
    connect(m_featuresTab->m_badnick, SIGNAL(toggled(bool)),
            this, SLOT(toggleBadnicknameTab(bool)));

	/* badchannelTab */
	m_badchannelTab = new Badchannel;
	connect(m_featuresTab->m_badchannel, SIGNAL(toggled(bool)),
		this, SLOT(toggleBadchannelTab(bool)));
            
    /* advertmsgTab */
    m_advertmsgTab = new Advertmsg;
    connect(m_featuresTab->m_advert, SIGNAL(toggled(bool)),
            this, SLOT(toggleAdvertmsgTab(bool)));
            
    /* statsmsgTab */
    m_statsmsgTab = new Statsmsg;
    connect(m_featuresTab->m_stats, SIGNAL(toggled(bool)),
            this, SLOT(toggleStatsmsgTab(bool)));
            
    /* protuserTab */
    m_protuserTab = new Protuser;
    connect(m_featuresTab->m_protuser, SIGNAL(toggled(bool)),
            this, SLOT(toggleProtuserTab(bool)));
    
    /* bottomLayout */
    QHBoxLayout *bottomLayout = new QHBoxLayout;
    bottomLayout->addWidget(m_copyright);
    bottomLayout->addStretch();
    bottomLayout->addWidget(m_currentFile);
    bottomLayout->addWidget(m_loadBtn);
    bottomLayout->addWidget(m_saveBtn);
    bottomLayout->addWidget(m_saveasBtn);
    
    /* mainLayout */
    QVBoxLayout *mainLayout = new QVBoxLayout;
    mainLayout->addWidget(m_tabWidget);
    mainLayout->addLayout(bottomLayout);
    centralWidget->setLayout(mainLayout);
}

void Configurator::toggleExtendedmsgTab(bool checked)
{
    if(checked)
    {
        m_tabWidget->addTab(m_extendedmsgTab, tr("Welcome Msg"));
    }
    else
    {
        int tabIndex = m_tabWidget->indexOf(m_extendedmsgTab);
        m_tabWidget->removeTab(tabIndex);
    }
}

void Configurator::toggleBadnicknameTab(bool checked)
{
    if(checked)
    {
        m_tabWidget->addTab(m_badnicknameTab, tr("Bad Nicknames"));
    }
    else
    {
        int tabIndex = m_tabWidget->indexOf(m_badnicknameTab);
        m_tabWidget->removeTab(tabIndex);
    }
}

void Configurator::toggleBadchannelTab(bool checked)
{
	if(checked)
	{
		m_tabWidget->addTab(m_badchannelTab, tr("Bad Channel"));
	}
	else
	{
		int tabIndex = m_tabWidget->indexOf(m_badchannelTab);
		m_tabWidget->removeTab(tabIndex);
	}
}

void Configurator::toggleAdvertmsgTab(bool checked)
{
    if(checked)
    {
        m_tabWidget->addTab(m_advertmsgTab, tr("Advert Msg"));
    }
    else
    {
        int tabIndex = m_tabWidget->indexOf(m_advertmsgTab);
        m_tabWidget->removeTab(tabIndex);
    }
}

void Configurator::toggleStatsmsgTab(bool checked)
{
    if(checked)
    {
        m_tabWidget->addTab(m_statsmsgTab, tr("Stats Msg"));
    }
    else
    {
        int tabIndex = m_tabWidget->indexOf(m_statsmsgTab);
        m_tabWidget->removeTab(tabIndex);
    }
}

void Configurator::toggleProtuserTab(bool checked)
{
    if(checked)
    {
        m_tabWidget->addTab(m_protuserTab, tr("Protected Users"));
    }
    else
    {
        int tabIndex = m_tabWidget->indexOf(m_protuserTab);
        m_tabWidget->removeTab(tabIndex);
    }
}

void Configurator::showLoadDialog()
{
    QString textDocs = tr("Configuration File");
    
    QString path = QFileDialog::getOpenFileName(
                   this,
                   tr("Choose a configuration file to load"),
                   "configs",
                   textDocs + " (*.ini)");
    
    if(path.isEmpty())
    {
        return;
    }
    
    QSettings settings(path, QSettings::IniFormat);
    
    m_commonTab->load(settings);
    m_featuresTab->load(settings);
    m_extendedmsgTab->load(settings);
    m_badnicknameTab->load(settings);
	m_badchannelTab->load(settings);
    m_advertmsgTab->load(settings);
    m_statsmsgTab->load(settings);
    m_protuserTab->load(settings);
    
    QFileInfo info(path);
    m_currentFile->setText(info.fileName());
}

void Configurator::showSaveAsDialog()
{
    bool ok;
    QString name = QInputDialog::getText(this, tr("Set File Name"),
                                             tr("File:"), QLineEdit::Normal,
                                             m_currentFile->text(), &ok);
    if(ok && !name.isEmpty())
    {
        QRegExp rx("*.ini");
        rx.setPatternSyntax(QRegExp::Wildcard);
        if(!rx.exactMatch(name))
        {
            name.append(".ini");
        }
    }
    else
    {
        return;
    }
    
    save(name);
}

void Configurator::showSaveDialog()
{
    if(m_currentFile->text().isEmpty())
    {
        showSaveAsDialog();
        return;
    }
    save(m_currentFile->text());
}

void Configurator::save(const QString &filename)
{
    QString path = QString("configs/") + filename;
    qDebug() << path;
    QSettings settings(path, QSettings::IniFormat);
    
    QFileInfo textDirInfo("text");
    if(!textDirInfo.exists())
    {
        QDir dir;
        dir.mkdir("text");
    }
    
    m_commonTab->save(settings);
    m_featuresTab->save(settings);
    m_extendedmsgTab->save(settings);
    m_badnicknameTab->save(settings);
	m_badchannelTab->save(settings);
    m_advertmsgTab->save(settings);
    m_statsmsgTab->save(settings);
    m_protuserTab->save(settings);
    
    m_currentFile->setText(filename);
}
