/**********************************************************************************
 * The Configurator allows to easily edit the TS2PerlMod config.
 * Copyright (C) 2006  Felix Siefert
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 **********************************************************************************/

#ifndef EDITOR_H
#define EDITOR_H

#include <QSyntaxHighlighter>
#include <QAction>
#include <QStringList>

class QTextEdit;
class Highlighter;
class QPushButton;
class QLabel;
class QMenu;

class Highlighter : public QSyntaxHighlighter
{
public:
    Highlighter(QStringList &keywords, QTextDocument *parent = 0);
    
protected:
    void highlightBlock(const QString &text);
    
private:
    struct HighlightingRule
    {
        QRegExp pattern;
        QTextCharFormat format;
    };
    QVector<HighlightingRule> highlightingRules;
    QTextCharFormat keywordFormat;
    
};

class Editor : public QWidget
{
    Q_OBJECT
    
public:
    Editor(bool commands = true, QWidget *parent = 0);
    void setFile(const QString &file);
    QString getFile() const;
    void setText(const QString &text);
    QString getText() const;
    
private slots:
    void onMenuAction(QAction *action);
    void showLoadDialog();
    void showNameDialog();
    
private:
    void setupCommandsMenu();
    
    QStringList     m_player_vars;
    QStringList     m_channel_vars;
    QStringList     m_server_vars;
    QStringList     m_all_vars;
    
    QTextEdit      *m_text;
    Highlighter    *m_highlighter;
    QPushButton    *m_commandsBtn;
    QPushButton    *m_loadBtn;
    QPushButton    *m_nameBtn;
    QLabel         *m_file;
    QMenu          *m_commandsMenu;
    QMenu          *m_player_commandsMenu;
    QMenu          *m_channel_commandsMenu;
    QMenu          *m_server_commandsMenu;
};

#endif
