/**********************************************************************************
 * The Configurator allows to easily edit the TS2PerlMod config.
 * Copyright (C) 2006  Felix Siefert
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 **********************************************************************************/

#include <QVBoxLayout>
#include <QHBoxLayout>
#include <QLabel>
#include <QFile>
#include <QFileInfo>
#include <QTextStream>
#include <QDebug>

#include "extendedmsg.h"
#include "settings.h"
#include "editor.h"

Extendedmsg::Extendedmsg(QWidget *parent) : QWidget(parent)
{
    m_description = new QLabel(tr("Sends a multi-line welcome message to every "
                                  "user connecting to your server. This message "
                                  "can contain special variables, that will be "
                                  "replaced with the appropriate values."));
    m_description->setWordWrap(true);
    m_editor      = new Editor;
    m_editor->setFile("welcome.txt");
    
    QVBoxLayout *mainLayout = new QVBoxLayout;
    mainLayout->addWidget(m_description);
    mainLayout->addWidget(m_editor);
    setLayout(mainLayout);
}

void Extendedmsg::load(QSettings &settings)
{
    QString path = settings.value("EXTENDED-WELCOME-MESSAGE/File").toString();
    if(path.isEmpty())
    {
        return;
    }
    path = QString("text/") + path;
    
    QFile file(path);
    file.open(QIODevice::ReadOnly);
    QTextStream stream(&file);
    
    m_editor->setText(stream.readAll());
    
    QFileInfo info(path);
    m_editor->setFile(info.fileName());
}

void Extendedmsg::save(QSettings &settings)
{
    QString filename = m_editor->getFile();
    settings.setValue("EXTENDED-WELCOME-MESSAGE/File", filename);
    QString path = QString("text/") + filename;
    
    QFile file(path);
    file.open(QIODevice::WriteOnly);
    QTextStream stream(&file);
    
    stream << m_editor->getText();
}
