/**********************************************************************************
 * The Configurator allows to easily edit the TS2PerlMod config.
 * Copyright (C) 2006  Felix Siefert
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 **********************************************************************************/

#ifndef FEATURES_H
#define FEATURES_H

#include <QWidget>
#include <QValidator>
#include <QSettings>

#include "settings.h"

class QLabel;
class QLineEdit;
class QSpinBox;
class QComboBox;
class QCheckBox;
class QPushButton;
class QGroupBox;

class InputWidget : public QWidget
{
    Q_OBJECT
    
public:
    InputWidget(const QString &label, int width = 0, QWidget *parent = 0);
    QString getText() const;
    void setText(const QString &text);
    void setValidator(const QValidator *v);
    
private:
    QLabel     *m_label;
    QLineEdit  *m_edit;

};

class TimeInput : public QWidget
{
    Q_OBJECT
    
public:
    TimeInput(const QString &label, int width = 0, bool sec = false, QWidget *parent = 0);
    int getTime() const;
    int getTimeMin() const;
    void setTimeSec(int sec);
    void setTimeMin(int min);
    
private:
    QLabel      *m_label;
    QSpinBox    *m_spinBox;
    QComboBox   *m_comboBox;
    
};

class Punishment : public QWidget
{
    Q_OBJECT
    
public:
    Punishment(QWidget *parent = 0);
    void setPunish(Settings::Pain pain);
    void setLabel(const QString &label);
    void setChannel(const QString &label);
    Settings::Pain getPunish() const;
    QString getPunishStr() const;
    QString getLabel() const;
    QString getChannel() const;
    
private slots:
    void onIndexChanged(const QString &text);
    
private:
    QLabel     *m_punishLabel;
    QComboBox  *m_comboBox;
    QLabel     *m_label;
    QLineEdit  *m_lineEdit;
    QLabel     *m_channelLabel;
    QLineEdit  *m_channel;

};

class Features : public QWidget
{
    Q_OBJECT
    
public:
    Features(QWidget *parent = 0);
    void load(QSettings &settings);
    void save(QSettings &settings);
    
    QCheckBox      *m_extendedmsg;
    QCheckBox      *m_badnick;
	QCheckBox      *m_badchannel;
    QCheckBox      *m_advert;
    QCheckBox      *m_stats;
    QCheckBox      *m_protuser;
    
private:
    bool cstb(Qt::CheckState state);  //checked state to bool
    
    QGroupBox      *m_advancedGroup;
    QGroupBox      *m_moveidlerGroup;
    QGroupBox      *m_warnidlerGroup;
    QGroupBox      *m_kickidlerGroup;
    QGroupBox      *m_autoafkGroup;
    QGroupBox      *m_antirecGroup;
    QGroupBox      *m_stickchannelGroup;
    QGroupBox      *m_antifloodGroup;
    QGroupBox      *m_takeoverGroup;
	QGroupBox      *m_autoservertypeGroup;
	QGroupBox      *m_updatebansGroup;
	QGroupBox      *m_bugdetectionGroup;
    
    Punishment     *m_antirecPunish;
    
    TimeInput      *m_moveidlerTime;
    InputWidget    *m_moveidlerInput;
    
    TimeInput      *m_warnidlerTime;
    InputWidget    *m_warnidlerInput;
    
    QPushButton    *m_kickidlerTargetBtn;
    QAction        *m_kiPlayerR;
    QAction        *m_kiPlayerU;
    QAction        *m_kiChannelR;
    QAction        *m_kiChannelU;
    
    TimeInput      *m_kickidlerTime;
    InputWidget    *m_kickidlerInput;
    
    InputWidget    *m_autoafkInput;
    
    InputWidget    *m_stickchannelInput;
    
    InputWidget    *m_antifloodMax;
    InputWidget    *m_antifloodSec;
    
    Punishment     *m_takeoverPunish;

	InputWidget    *m_autotypeClients;
	InputWidget    *m_autotypeInterval;

	TimeInput      *m_updatebansTime;

	QLabel         *m_bugdetectionLabel;
};

#endif /* FEATURES_H */
