/**********************************************************************************
 * The Configurator allows to easily edit the TS2PerlMod config.
 * Copyright (C) 2006  Felix Siefert
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 **********************************************************************************/

#include <QVBoxLayout>
#include <QHBoxLayout>
#include <QLabel>
#include <QFile>
#include <QFileInfo>
#include <QTextStream>

#include "protuser.h"
#include "settings.h"
#include "editor.h"

Protuser::Protuser(QWidget *parent) : QWidget(parent)
{
    m_description = new QLabel(tr("Allows you to create a list of loginnames "
                                  "that are protected. These users will be ignored "
                                  "by the TS2PerlMod. This list is handled case "
                                  "sensitive, so <b>scp</b> won't match <b>ScP</b>."));
    m_description->setWordWrap(true);
    m_editor      = new Editor(false);
    m_editor->setFile("protected.txt");
    
    
    QVBoxLayout *mainLayout = new QVBoxLayout;
    mainLayout->addWidget(m_description);
    mainLayout->addWidget(m_editor);
    setLayout(mainLayout);
}

void Protuser::load(QSettings &settings)
{
    QString path = settings.value("PROTECTED-USERS/File").toString();
    if(path.isEmpty())
    {
        return;
    }
    path = QString("text/") + path;
    
    QFile file(path);
    file.open(QIODevice::ReadOnly);
    QTextStream stream(&file);
    
    m_editor->setText(stream.readAll());
    
    QFileInfo info(path);
    m_editor->setFile(info.fileName());
}

void Protuser::save(QSettings &settings)
{
    QString filename = m_editor->getFile();
    settings.setValue("PROTECTED-USERS/File", filename);
    QString path = QString("text/") + filename;
    
    QFile file(path);
    file.open(QIODevice::WriteOnly);
    QTextStream stream(&file);
    
    stream << m_editor->getText();
}
